biom.table.Table.to_json — biom-format.org

# biom-format.org

## biom.table.Table.to_json

`Table.` `to_json`(generated_by, direct_io=None)

  Returns a JSON string representing the table in BIOM format.

  Parameters: | generated_by : str a string describing the software used to build the table direct_io : file or file-like object, optional Defaults to `None`. Must implementing a `write` function. If direct_io is not `None`, the final output is written directly to direct_io during processing.
  Returns: | str A JSON-formatted string representing the biom table